@@ -110,7 +110,7 @@ def is_list_str(x, opname, n = None):
 
 def is_nonnegative(x):
     if not isinstance(x, int):
-        msg1 = "pop.at_least must be an integer, not of type {}."
+        msg1 = "pop.at_least must be an integer, not of {}."
         raise TypeError(msg1.format(type(x)))
     if x < 0:
         msg2 = "pop.at_least must be a nonnegative integer, not {}."
@@ -480,16 +480,25 @@ def _get_single_key(pat: str):
     
     return key
 
-def _reset_option(pat: str):
-    keys = _select_options(pat)
+def _reset_option(*args):
+    nargs = len(args)
+    pat = None
+    keys = None
+    if nargs == 1:
+        pat = args[0]
+        keys = _select_options(pat)
+    else:
+        for patt in args:
+            _reset_option(patt)
+        return None
 
     if len(keys) == 0:
-        raise KeyError("No such keys(s)")
+        raise KeyError("No such key(s)")
 
     if len(keys) > 1 and len(pat) < 4 and pat != "all":
         raise ValueError(
             "You must specify at least 4 characters when "
-            "resetting multiple keys, use the special keyword "
+            "resetting multiple keys; use the special keyword "
             '"all" to reset all the options to their default value'
         )
 
